<template>
  <PageWrapper :title="bt('领料单的资料', [BILLCODE])" :content="bt('这是领料单详情页面。')" contentBackground @back="goBack">
    <template #footer>
      <a-tabs default-active-key="detail" v-model:activeKey="currentKey" @tabClick="tabClkcallback">
        <a-tab-pane key="detail" :tab="bt('单据详情')" />
        <a-tab-pane key="detailsn" :tab="bt('条码详情')" />
      </a-tabs>
    </template>
    <div>
      <div v-if="currentKey == 'detail'">
        <BasicTable @register="detailTable">
          <template #toolbar>
            <a-button preIcon="OutR|svg" ghost color="success" @click="aoaToExceldtl"> 导出 </a-button>
          </template>
          <template #action="{ record }">
            <TableAction :actions="[
              {
                icon: 'clarity:info-standard-line',
                tooltip: bt('查看条码详情'),
                onClick: JumpSnDetail.bind(null, record),
              }
            ]" />
          </template>
        </BasicTable>
      </div>
      <div v-if="currentKey == 'detailsn'">
        <BasicTable @register="detailsnTable">
          <template #toolbar>
            <a-button preIcon="OutR|svg" ghost color="success" @click="aoaToExcelsn"> 导出 </a-button>
          </template>
        </BasicTable>
      </div>
    </div>
    <Loading :loading="compState.loading" :tip="compState.tip" />
  </PageWrapper>
  
</template>

<script lang="ts" setup>
import { aoaToSheetXlsx } from '/@/components/Excel';

import { ref, reactive } from 'vue';
import { useRoute } from 'vue-router';
import { PageWrapper } from '/@/components/Page';
import { useTabs } from '/@/hooks/web/useTabs';
import { Tabs } from 'ant-design-vue';
import { useGo } from '/@/hooks/web/usePage';
//详情列表
import { BasicTable, useTable, TableAction } from '/@/components/Table';
import { getMaterialReqDetailListByPage, getMaterialReqDetailSNListByPage } from '/@/api/tigerapi/wms/materialreq';
import { columns_D, columns_S, searchFormSchema_D, searchFormSchema_S } from './materialreq.data';
import { useI18n } from '/@/hooks/web/useI18n';
import { Loading } from '/@/components/Loading';
import { useMessage } from '/@/hooks/web/useMessage';
const { t: bt } = useI18n();
const { createMessage } = useMessage();
//ATabs: Tabs, ATabPane: Tabs.TabPane
const compState = reactive({
  absolute: false,
  loading: false,
  tip: '加载中...',
});
const ATabs = ref(Tabs)
const ATabPane = ref(Tabs.TabPane)
const route = useRoute();
var ITEM_CODE = ref('');
const go = useGo();
//获取JobId
const BILLCODE = ref(route.params?.BillCode);
const [detailTable, { getForm: DataDtl, getPaginationRef: DataPDtl }] = useTable({
  title: bt('单据详情列表'),
  api: getMaterialReqDetailListByPage,
  columns: columns_D,
  useSearchForm: true,
  showTableSetting: true,
  bordered: true,
  canResize: true,
  showIndexColumn: false,
  formConfig: {
    labelWidth: 120,
    schemas: searchFormSchema_D,
  },
  actionColumn: {
    width: 80,
    title: bt('操作'),
    dataIndex: 'action',
    slots: { customRender: 'action' },
    fixed: 'right' //undefined,
  },
  searchInfo: { BILLCODE },
});
const [detailsnTable, { getForm: DataSn, getPaginationRef: DataPSn }] = useTable({
  title: bt('条码详情列表'),
  api: getMaterialReqDetailSNListByPage,
  columns: columns_S,
  formConfig: {
    labelWidth: 120,
    schemas: searchFormSchema_S,
    model: { ITEM_CODE: ITEM_CODE }
  },
  useSearchForm: true,
  searchInfo: { BILLCODE },
  showTableSetting: false,
  bordered: true,
  canResize: true,
  showIndexColumn: false,
});

let arrdtl: any[] = [];
let arrsn: any[] = [];
function aoaToExceldtl() {
  const totals = DataPDtl().total
  if (totals < 30000) {
    arrdtl = [];
    compState.loading = true;
    const col = DataDtl().getFieldsValue()
    col.BILLCODE = BILLCODE.value
    getMaterialReqDetailListByPage(col).then((data) => {
      data.items.forEach(element => {
        let start = ''
        switch (element.LINESTATUS) {
          case 0:
            start = bt('初始化');
            break;
          case 1:
            start = bt('清点中');
            break;
          case 2:
            start = bt('作业中');
            break;
          case 3:
            start = bt('超发');
            break;
          case 4:
            start = bt('完成');
            break;
          default:
            break;
        }
        arrdtl.push({
          '序号': element.BILLLINE,
          '料号': element.ITEM_CODE,
          '物料描述': element.ITEM_NAME,
          '状态': start,
          '操作时间': element.UPDATE_TIME,
          '仓库': element.WAREHOUSECODE,
          '需求数量': element.PRQTY,
          '已发数量': element.QTY,
          '欠发数量': element.OWE_QTY,
        });
      });
      const arrHeader = columns_D.slice(3).map((column) => column.title);
      const arrData = arrdtl.map((item) => {
        return Object.keys(item).map((key) => item[key]);
      });
      // 保证data顺序与header一致

      if (arrdtl.length < 30000) {
        aoaToSheetXlsx({
          data: arrData,
          header: arrHeader,
          filename: '领料单明细.xlsx',
        });
      } else {
        createMessage.error(bt('导出数据不能超过三万条，如需要更多的请联系管理员'));
      }
    })
  }else{
    createMessage.error(bt('导出数据不能超过三万条，如需要更多的请联系管理员'));
  }
  compState.loading=false;
}

function aoaToExcelsn() {
  const totals = DataPSn().total
  if (totals < 30000) {
    arrsn = [];
    compState.loading = true;
    const col = DataSn().getFieldsValue()
    col.BILLCODE = BILLCODE.value
    getMaterialReqDetailSNListByPage(col).then((data) => {
      data.items.forEach(element => {
        let start = ''
        switch (element.STATUS) {
          case 0:
            start = bt('不存在');
            break;
          case 10:
            start = bt('送货中');
            break;
          case 20:
            start = bt('待检验');
            break;
          case 30:
            start = bt('待入库');
            break;
          case 40:
            start = bt('在库中');
            break;
          case 50:
            start = bt('已下架');
            break;
          case 60:
            start = bt('已发料');
            break;
          case 70:
            start = bt('已上料');
            break;
          case 80:
            start = bt('已耗尽');
            break;
          case 90:
            start = bt('已退料');
            break;
          case 100:
            start = bt('已发货');
            break;
          default:
            break;
        }
        arrsn.push({
          '条码': element.SN,
          '修改时间':element.UPDATE_TIME,
          '状态': start,
          '物料编码': element.ITEM_CODE,
          '库存数量': element.QTY,
          '发料数量': element.ALLOC_QTY,
        });
      });
      const arrHeader = columns_S.slice(3).map((column) => column.title);
      const arrData = arrsn.map((item) => {
        return Object.keys(item).map((key) => item[key]);
      });
      // 保证data顺序与header一致

      if (arrdtl.length < 30000) {
        aoaToSheetXlsx({
          data: arrData,
          header: arrHeader,
          filename: '领料单条码明细.xlsx',
        });
      } else {
        createMessage.error(bt('导出数据不能超过三万条，如需要更多的请联系管理员'));
      }
      compState.loading=false;
    })
  }
}

// 此处可以得到用户ID
//const BILLCODE = ref(route.params?.BILLCODE.split(',')[1]);
var currentKey = ref('detail');
const { setTitle } = useTabs();
// TODO
// 本页代码仅作演示，实际应当通过userId从接口获得用户的相关资料

// 设置Tab的标题（不会影响页面标题）
setTitle(bt('详情：单据') + BILLCODE.value);

// 页面左侧点击返回链接时的操作
function goBack() {
  // 本例的效果时点击返回始终跳转到账号列表页，实际应用时可返回上一页
  go('/materialreq');
}
const tabClkcallback = (val: string) => {
  if (val == 'detail') {
    ITEM_CODE.value = '';
  }
};
function JumpSnDetail(record: Recordable) {
  currentKey.value = 'detailsn'
  ITEM_CODE.value = record.ITEM_CODE
}
</script>
